==> neper-1.8.0.tgz: neper-1.8.0/src/Utils/GeoUtils/Geo2Geo/Geo2Geo.h <==
/* This file is part of the 'neper' program. */
/* Copyright (C) 2004-2009, Romain Quey. */
/* See the COPYING file in the top-level directory. */

#include<stdio.h>
#include<stdlib.h>
#include<math.h>

#include"../../Structs/structPolyMod.h"
#include"../../Structs/structPoly.h"
#include"../../Structs/structTess.h"
#include"../../Structs/structGeo.h"
#include"../../Structs/structGeoPara.h"
#include"../../BoardUtils/BoardUtils0.h"

#include"Geo2Geo0.h"

extern void GeoAlloc (struct GEO *);
extern void Geo2GeoGen (struct GEO, struct GEO *);
extern void Geo2GeoVer (struct GEO, struct GEO *);
extern void Geo2GeoVerQty (struct GEO, struct GEO *);
extern void Geo2GeoVerCoo (struct GEO, struct GEO *);
extern void Geo2GeoVerEdge (struct GEO, struct GEO *);
extern void Geo2GeoVerBound (struct GEO, struct GEO *);
extern void Geo2GeoVerState (struct GEO, struct GEO *);
extern void Geo2GeoVerLength (struct GEO, struct GEO *);
extern void Geo2GeoEdge (struct GEO, struct GEO *);
extern void Geo2GeoEdgeQty (struct GEO, struct GEO *);
extern void Geo2GeoEdgeVerNb (struct GEO, struct GEO *);
extern void Geo2GeoEdgeFace (struct GEO, struct GEO *);
extern void Geo2GeoEdgeLength (struct GEO, struct GEO *);
extern void Geo2GeoEdgeState (struct GEO, struct GEO *);
extern void Geo2GeoEdgeDel (struct GEO, struct GEO *);
extern void Geo2GeoFace (struct GEO, struct GEO *, int);
extern void Geo2GeoFaceQty (struct GEO, struct GEO *);
extern void Geo2GeoFaceGerm (struct GEO, struct GEO *);
extern void Geo2GeoFaceVer (struct GEO, struct GEO *, int);
extern void Geo2GeoFaceEdge (struct GEO, struct GEO *, int);
extern void Geo2GeoFaceFF (struct GEO, struct GEO *);
extern void Geo2GeoFaceEq (struct GEO, struct GEO *);
extern void Geo2GeoFaceBound (struct GEO, struct GEO *);
extern void Geo2GeoFaceState (struct GEO, struct GEO *);
extern void Geo2GeoFaceDis (struct GEO, struct GEO *);
extern void Geo2GeoFacePt (struct GEO, struct GEO *);
extern void Geo2GeoPoly (struct GEO, struct GEO *, int);
extern void Geo2GeoPolyQty (struct GEO, struct GEO *);
extern void Geo2GeoPolyFace (struct GEO, struct GEO *, int);
extern void Geo2GeoDomain (struct GEO, struct GEO *, int);
extern void Geo2GeoDomainSize (struct GEO, struct GEO *, int);

==> neper-1.8.1.tgz: neper-1.8.1/src/Utils/GeoUtils/Geo2Geo/Geo2Geo.h <==
/* This file is part of the 'neper' program. */
/* Copyright (C) 2003-2009, Romain Quey. */
/* See the COPYING file in the top-level directory. */

#include<stdio.h>
#include<stdlib.h>
#include<math.h>

#include"../../../neut/neut.h"
#include"../../Structs/structPolyMod.h"
#include"../../Structs/structPoly.h"
#include"../../Structs/structGeo.h"
#include"../../Structs/structGeoPara.h"
#include"../../BoardUtils/BoardUtils0.h"

#include"Geo2Geo0.h"

extern void GeoAlloc (struct GEO *);
extern void Geo2GeoGen (struct GEO, struct GEO *);
extern void Geo2GeoVer (struct GEO, struct GEO *);
extern void Geo2GeoVerQty (struct GEO, struct GEO *);
extern void Geo2GeoVerCoo (struct GEO, struct GEO *);
extern void Geo2GeoVerEdge (struct GEO, struct GEO *);
extern void Geo2GeoVerBound (struct GEO, struct GEO *);
extern void Geo2GeoVerState (struct GEO, struct GEO *);
extern void Geo2GeoVerLength (struct GEO, struct GEO *);
extern void Geo2GeoEdge (struct GEO, struct GEO *);
extern void Geo2GeoEdgeQty (struct GEO, struct GEO *);
extern void Geo2GeoEdgeVerNb (struct GEO, struct GEO *);
extern void Geo2GeoEdgeFace (struct GEO, struct GEO *);
extern void Geo2GeoEdgeLength (struct GEO, struct GEO *);
extern void Geo2GeoEdgeState (struct GEO, struct GEO *);
extern void Geo2GeoEdgeDel (struct GEO, struct GEO *);
extern void Geo2GeoFace (struct GEO, struct GEO *, int);
extern void Geo2GeoFaceQty (struct GEO, struct GEO *);
extern void Geo2GeoFaceGerm (struct GEO, struct GEO *);
extern void Geo2GeoFaceVer (struct GEO, struct GEO *, int);
extern void Geo2GeoFaceEdge (struct GEO, struct GEO *, int);
extern void Geo2GeoFaceFF (struct GEO, struct GEO *);
extern void Geo2GeoFaceEq (struct GEO, struct GEO *);
extern void Geo2GeoFaceBound (struct GEO, struct GEO *);
extern void Geo2GeoFaceState (struct GEO, struct GEO *);
extern void Geo2GeoFaceDis (struct GEO, struct GEO *);
extern void Geo2GeoFacePt (struct GEO, struct GEO *);
extern void Geo2GeoPoly (struct GEO, struct GEO *, int);
extern void Geo2GeoPolyQty (struct GEO, struct GEO *);
extern void Geo2GeoPolyFace (struct GEO, struct GEO *, int);
extern void Geo2GeoDomain (struct GEO, struct GEO *, int);
extern void Geo2GeoDomainSize (struct GEO, struct GEO *, int);
